# from django.shortcuts import render
from rest_framework.viewsets import ViewSet
from rest_framework.response import Response
from django.http import HttpResponse
from django.shortcuts import get_object_or_404

from image.models import Image
from image.serializers import ImageSerializer


class ImageViewSet(ViewSet):

    def list(self, request):
        images = Image.object.all()
        serializer = ImageSerializer(images, many=True)
        return HttpResponse(serializer.data)

    def create(self, request):
        serializer = ImageSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        data = serializer.validated_data
        new_image = Image.create_from_user(
            description=data['description'],
            file_format=data['file_format'],
            image_file=data['image_file'],
            name=data['name'],
            user=request.user
        )
        serializer = ImageSerializer(instance=new_image)
        return Response(serializer.data)
    
    def retrieve(self, request, pk=None):
       return Response(status=status.HTTP_204_NO_CONTENT)


    def update(self, request, pk=None):
        return HttpResponse("update")

    def partial_update(self, request, pk=None):
        return HttpResponse("patch")

    def destroy(self, request, pk=None):
        queryset = Image.objects.all()
        image = get_object_or_404(queryset, pk=pk)
        image.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)
